@@ -76,7 +76,7 @@ of the namespace portion :mod:`ae.gui_help`.
 
 
 """
-from typing import cast
+from typing import Callable, cast
 
 from kivy.input import MotionEvent                                                          # type: ignore
 from kivy.lang import Builder                                                               # type: ignore
@@ -84,7 +84,6 @@ from kivy.lang import Builder
 from kivy.properties import BooleanProperty, DictProperty, ObjectProperty, StringProperty   # type: ignore
 from kivy.uix.image import Image                                                            # type: ignore
 from kivy.uix.scrollview import ScrollView                                                  # type: ignore
-from kivy.uix.widget import Widget                                                          # type: ignore
 from kivy.app import App                                                                    # type: ignore
 
 from ae.core import main_app_instance                                                       # type: ignore
@@ -92,7 +91,7 @@ from ae.gui_help import HelpAppBase
 from ae.kivy_relief_canvas import ReliefCanvas                                              # type: ignore
 
 
-__version__ = '0.1.10'
+__version__ = '0.1.11'
 
 
 Builder.load_string("""\
@@ -178,12 +177,15 @@ Builder.load_string("""\
 """)
 
 
-class HelpBehavior(Widget):
+class HelpBehavior:
     """ behaviour mixin class for widgets having help texts. """
     help_id = StringProperty()      #: unique help id of the widget
     help_lock = BooleanProperty()   #: True if the help mode is active and this widget is not the help target
     help_vars = DictProperty()      #: dict of extra data for to displayed/render the help text of this widget
 
+    # attributes and methods provided by the class to be mixed into
+    collide_point: Callable
+
     def on_touch_down(self, touch: MotionEvent) -> bool:                                    # pragma: no cover
         """ prevent any processing if touch is done on the help activator widget or in active help mode.
 
@@ -199,7 +201,8 @@ class HelpBehavior(Widget):
             if main_app.help_display(self.help_id, self.help_vars):
                 return True
 
-        return super().on_touch_down(touch)
+        # noinspection PyUnresolvedReferences
+        return super().on_touch_down(touch)                 # type: ignore # pylint: disable=no-member # false positive
 
 
 class HelpLayout(ScrollView):                                                           # pragma: no cover
